@@ -65,10 +65,6 @@ class DynamicSetting(object):
         self.download_timeout = download_timeout
         self.data_ttl = self.max_age.total_seconds() + self.data_margin_seconds
 
-        if self.logger:
-            self.logger.setDefaultData(data={'slug': self.slug,
-                                             'instance_id': self.instance_id,
-                                             'url': self.url})
         self.attach_scripts_to_redis_client()
 
     @classmethod
@@ -180,7 +176,7 @@ class DynamicSetting(object):
 
     def load_from_file(self):
 
-        self.logger.warning('Loading settings from file')
+        self.logger.warning('Loading settings from file', data=self.log_data)
         if self.verbose:
             print(f'{self.slug} - Loading from disk')
         latest_files = [fn for fn in [self.parse_filename(filename) for filename in os.listdir(self.data_dir)
@@ -266,7 +262,7 @@ class DynamicSetting(object):
         if hasattr(self, 'validate_' + self.slug) and callable(getattr(self, 'validate_' + self.slug)):
             valid, error_message = getattr(self, 'validate_' + self.slug)(data)
             if not valid:
-                self.logger.error(f'Response from url did not validate', data={'error': error_message})
+                self.logger.error(f'Response from url did not validate', data={'error': error_message, **self.log_data})
                 return
         return data
 
@@ -274,7 +270,8 @@ class DynamicSetting(object):
 
         if not self.version_subkey is None:
             if not isinstance(data, dict) or not self.version_subkey in data:
-                self.logger.error(f'Response from url should be a JSON object containing the key {self.version_subkey}')
+                self.logger.error(f'Response from url should be a JSON object containing the key {self.version_subkey}',
+                                  data=self.log_data)
                 return None, None
             version = str(data[self.version_subkey])
         else:
@@ -283,7 +280,8 @@ class DynamicSetting(object):
 
         if not self.download_subkey is None:
             if not isinstance(data, dict) or not self.download_subkey in data:
-                self.logger.error(f'Response from url should be a JSON object containing the key {self.download_subkey}')
+                self.logger.error(f'Response from url should be a JSON object containing the key {self.download_subkey}',
+                                  data=self.log_data)
                 return None, None
             data = data[self.download_subkey]
 
@@ -319,15 +317,16 @@ class DynamicSetting(object):
                 print(f'{self.slug} - Downloading...')
             r = self.session.get(url=self.url, **self.download_options, timeout=self.download_timeout)
             r.raise_for_status()
-            self.logger.info('Downloaded data from url')
+            self.logger.info('Downloaded data from url',
+                             data=self.log_data)
         except requests.exceptions.RequestException as e:
-            self.logger.error('Failed to get data from url', data={'error': str(e)})
+            self.logger.error('Failed to get data from url', data={'error': str(e), **self.log_data})
             return
 
         try:
             data = r.json()
         except json.JSONDecodeError:
-            self.logger.error('Response from url was no valid json')
+            self.logger.error('Response from url was no valid json', data=self.log_data)
             return
 
         version, data = self.parse_download_data(data=data)
@@ -540,3 +539,10 @@ class DynamicSetting(object):
             d.update({'reason': reason})
         return d
 
+    @property
+    def log_data(self):
+
+        return {'slug': self.slug,
+                'instance_id': self.instance_id,
+                'url': self.url}
+
